@@ -293,8 +293,8 @@ class VectorSearchTool(BaseTool):
 class ListAgentsInput(BaseModel):
     """Input schema for list agents tool."""
     limit: int = Field(
-        default=10,
-        description="Maximum number of agents to return (default: 10, max: 10)"
+        default=20,
+        description="Maximum number of agents to return (default: 20, max: 20)"
     )
     tags: Optional[List[str]] = Field(
         default=None,
@@ -328,17 +328,13 @@ class ListAgentsTool(BaseTool):
     
     def _run(
         self, 
-        limit: int = 10, 
+        limit: int = 20,
         tags: Optional[List[str]] = None, 
         capabilities: Optional[List[str]] = None, 
         active_only: bool = True
     ) -> str:
         """Execute list agents operation."""
         try:
-            # Enforce maximum limit of 10
-            if limit > 10:
-                limit = 10
-            
             logger.info(f"Listing utility agents: limit={limit}, tags={tags}, capabilities={capabilities}, active_only={active_only}")
             
             # Use list_utility_agents to get the list
